@@ -91,12 +91,13 @@ struct sgttyb tty_cooked, tty_cbreak;
 
 int interactive, tty_charmode;
 
-extern char **environ, *tgoto(), *tgetstr();
+extern char **environ;
 
 char *termcap_ptr;
 
-int termcap_putter(char ch) {
-    *termcap_ptr++ = ch;
+int termcap_putter(int ch) {
+    /* XXX: Should this check for any non-char values? */
+    *termcap_ptr++ = (char)ch;
     return 0;
 }
 
